# ConnectorFieldDataType


## Enum

* `STRING` (value: `'string'`)

* `DICT` (value: `'dict'`)

* `ENUM` (value: `'enum'`)

* `INT` (value: `'int'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


